@@ -2,7 +2,7 @@
 # coding: utf-8
 
 __author__ = "ChenyangGao <https://chenyanggao.github.io>"
-__version__ = (0, 1, 4)
+__version__ = (0, 1, 5)
 __all__ = ["urlopen", "request", "download"]
 
 from collections import defaultdict, deque, UserString
@@ -10,7 +10,7 @@ from collections.abc import Buffer, Callable, Generator, Iterable, Mapping
 from copy import copy
 from http.client import HTTPConnection, HTTPSConnection, HTTPResponse
 from http.cookiejar import CookieJar
-from http.cookies import SimpleCookie
+from http.cookies import BaseCookie
 from inspect import isgenerator
 from os import fsdecode, fstat, makedirs, PathLike
 from os.path import abspath, dirname, isdir, join as joinpath
@@ -29,7 +29,7 @@ from urllib.request import (
 from argtools import argcount
 from cookietools import cookies_to_str, extract_cookies, update_cookies
 from dicttools import iter_items
-from filewrap import bio_skip_iter, bio_chunk_iter, SupportsRead, SupportsWrite
+from filewrap import bio_skip_iter, SupportsRead, SupportsWrite
 from http_request import normalize_request_args, SupportsGeturl
 from http_response import (
     decompress_response, get_filename, get_length, is_chunked, is_range_request, 
@@ -81,7 +81,7 @@ class HTTPCookieProcessor(BaseHandler):
     def __init__(
         self, 
         /, 
-        cookies: None | CookieJar | SimpleCookie = None, 
+        cookies: None | CookieJar | BaseCookie = None, 
     ):
         if cookies is None:
             cookies = CookieJar()
@@ -90,7 +90,7 @@ class HTTPCookieProcessor(BaseHandler):
     def http_request(self, request):
         cookies = self.cookies
         if cookies:
-            if isinstance(cookies, SimpleCookie):
+            if isinstance(cookies, BaseCookie):
                 cookies = update_cookies(CookieJar(), cookies)
             cookies.add_cookie_header(request)
         return request
@@ -264,7 +264,7 @@ def urlopen(
     follow_redirects: bool = True, 
     proxies: None | Mapping[str, str] | Iterable[tuple[str, str]] = None, 
     context: None | SSLContext = None, 
-    cookies: None | CookieJar | SimpleCookie = None, 
+    cookies: None | CookieJar | BaseCookie = None, 
     timeout: None | Undefined | float = undefined, 
     opener: None | OpenerDirector = _opener, 
     **_, 
@@ -273,19 +273,28 @@ def urlopen(
         request = url
     else:
         if isinstance(data, PathLike):
-            data = bio_chunk_iter(open(data, "rb"))
-        elif isinstance(data, SupportsRead):
-            data = bio_chunk_iter(data)
-        request = Request(**normalize_request_args( # type: ignore
-            method=method, 
-            url=url, 
-            params=params, 
-            data=data, 
-            json=json, 
-            files=files, 
-            headers=headers, 
-            ensure_ascii=True, 
-        ))
+            data = open(data, "rb")
+        if isinstance(data, SupportsRead):
+            request_args = normalize_request_args(
+                method=method, 
+                url=url, 
+                params=params, 
+                headers=headers, 
+                ensure_ascii=True, 
+            )
+            request_args["data"] = data # type: ignore
+        else:
+            request_args = normalize_request_args(
+                method=method, 
+                url=url, 
+                params=params, 
+                data=data, 
+                json=json, 
+                files=files, 
+                headers=headers, 
+                ensure_ascii=True, 
+            )
+        request = Request(**request_args) # type: ignore
         if proxies:
             for host, type in iter_items(proxies):
                 request.set_proxy(host, type)
@@ -374,7 +383,7 @@ def request(
     headers: None | Mapping[string, string] | Iterable[tuple[string, string]] = None, 
     follow_redirects: bool = True, 
     raise_for_status: bool = True, 
-    cookies: None | CookieJar | SimpleCookie = None, 
+    cookies: None | CookieJar | BaseCookie = None, 
     *, 
     parse: None | EllipsisType = None, 
     **request_kwargs, 
@@ -391,7 +400,7 @@ def request(
     headers: None | Mapping[string, string] | Iterable[tuple[string, string]] = None, 
     follow_redirects: bool = True, 
     raise_for_status: bool = True, 
-    cookies: None | CookieJar | SimpleCookie = None, 
+    cookies: None | CookieJar | BaseCookie = None, 
     *, 
     parse: Literal[False], 
     **request_kwargs, 
@@ -408,7 +417,7 @@ def request(
     headers: None | Mapping[string, string] | Iterable[tuple[string, string]] = None, 
     follow_redirects: bool = True, 
     raise_for_status: bool = True, 
-    cookies: None | CookieJar | SimpleCookie = None, 
+    cookies: None | CookieJar | BaseCookie = None, 
     *, 
     parse: Literal[True], 
     **request_kwargs, 
@@ -425,7 +434,7 @@ def request[T](
     headers: None | Mapping[string, string] | Iterable[tuple[string, string]] = None, 
     follow_redirects: bool = True, 
     raise_for_status: bool = True, 
-    cookies: None | CookieJar | SimpleCookie = None, 
+    cookies: None | CookieJar | BaseCookie = None, 
     *, 
     parse: Callable[[HTTPResponse, bytes], T] | Callable[[HTTPResponse], T], 
     **request_kwargs, 
@@ -441,7 +450,7 @@ def request[T](
     headers: None | Mapping[string, string] | Iterable[tuple[string, string]] = None, 
     follow_redirects: bool = True, 
     raise_for_status: bool = True, 
-    cookies: None | CookieJar | SimpleCookie = None, 
+    cookies: None | CookieJar | BaseCookie = None, 
     *, 
     parse: None | EllipsisType| bool | Callable[[HTTPResponse, bytes], T] | Callable[[HTTPResponse], T] = None, 
     **request_kwargs, 
